const GObject = imports.gi.GObject;
const Gtk = imports.gi.Gtk;
const Gio = imports.gi.Gio;
const GLib = imports.gi.GLib;

const ScreenshotDirectory = GObject.registerClass(
class ScreenshotDirectory extends Gtk.Box
{
    _init()
    {
        super._init({orientation: Gtk.Orientation.VERTICAL, margin_start: 20, margin_top: 20, margin_end: 20});

        if (Gtk.get_major_version() < 4)
        {
            this.connect('destroy', Gtk.main_quit);

            this.fileChooser = new Gtk.FileChooserButton({action: Gtk.FileChooserAction.SELECT_FOLDER});
            this.pack_start(this.fileChooser, false, false, 0);
            this.fileChooser.connect('file-set', (dlg) => this._response(dlg, Gtk.ResponseType.ACCEPT));
        }
        else
        {
            this.fileChooser = new Gtk.FileChooserNative({action: Gtk.FileChooserAction.SELECT_FOLDER});
            this.fileChooser.connect('response', (dlg, response) => this._response(dlg, response));
            this.button = new Gtk.Button();
            this.button.connect('clicked', () => this.show());
            this.append(this.button);
        }

        this._settings = new Gio.Settings({schema_id: 'org.gnome.gnome-screenshot'});
        this._settings.connect('changed', this._sync.bind(this));

        this._sync();
    }

    show()
    {
        this.fileChooser.set_transient_for(this.get_root());
        this.fileChooser.show();
    }

    _response(dlg, response)
    {
        if (response != Gtk.ResponseType.ACCEPT)
            return;

        this._settings.set_string('auto-save-directory', dlg.get_file().get_path());
    }

    _sync()
    {
        const dir = this._settings.get_string('auto-save-directory').replace(/^file:\/\/\//, '/');

        if (GLib.file_test(dir, GLib.FileTest.EXISTS))
        {
            this.fileChooser.set_file(Gio.File.new_for_path(dir));

            if (Gtk.get_major_version() == 4)
                this.button.label = dir;
        }
    }
});

function buildPrefsWidget()
{
    let widget = new ScreenshotDirectory();

    if (Gtk.get_major_version() < 4)
        widget.show_all();

    return widget;
}

function init()
{
}
